<?php
/*
Plugin Name: Age Verification Popup
Description: A simple age verification popup for WordPress that only appears once and allows text customization.
Version: 1.5
Author: EasyToolsWP
*/

function avp_add_settings_page() {
    add_options_page('Age Verification Settings', 'Age Verification', 'manage_options', 'age-verification', 'avp_render_settings_page');
}
add_action('admin_menu', 'avp_add_settings_page');

function avp_render_settings_page() {
    ?>
    <div class="wrap">
        <h1>Age Verification Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('avp_settings_group');
            do_settings_sections('age-verification');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

function avp_register_settings() {
    register_setting('avp_settings_group', 'avp_heading');
    register_setting('avp_settings_group', 'avp_button_text');
    register_setting('avp_settings_group', 'avp_confirm_text');
    register_setting('avp_settings_group', 'avp_warning_text');
    register_setting('avp_settings_group', 'avp_accept_warning_text');

    add_settings_section('avp_main_section', 'Customize Texts', null, 'age-verification');

    add_settings_field('avp_heading', 'Popup Heading', 'avp_render_heading_field', 'age-verification', 'avp_main_section');
    add_settings_field('avp_button_text', 'Button Text', 'avp_render_button_field', 'age-verification', 'avp_main_section');
    add_settings_field('avp_confirm_text', 'Confirmation Text', 'avp_render_confirm_field', 'age-verification', 'avp_main_section');
    add_settings_field('avp_warning_text', 'Warning Message', 'avp_render_warning_field', 'age-verification', 'avp_main_section');
    add_settings_field('avp_accept_warning_text', 'Acceptance Warning Message', 'avp_render_accept_warning_field', 'age-verification', 'avp_main_section');
}
add_action('admin_init', 'avp_register_settings');

function avp_render_heading_field() {
    echo '<input type="text" name="avp_heading" value="' . esc_attr(get_option('avp_heading', 'Enter your birthdate')) . '" size="50">';
}
function avp_render_button_field() {
    echo '<input type="text" name="avp_button_text" value="' . esc_attr(get_option('avp_button_text', 'Enter')) . '" size="50">';
}
function avp_render_confirm_field() {
    echo '<input type="text" name="avp_confirm_text" value="' . esc_attr(get_option('avp_confirm_text', 'I confirm that I am over 18 years old')) . '" size="50">';
}
function avp_render_warning_field() {
    echo '<input type="text" name="avp_warning_text" value="' . esc_attr(get_option('avp_warning_text', 'You are not old enough')) . '" size="50">';
}
function avp_render_accept_warning_field() {
    echo '<input type="text" name="avp_accept_warning_text" value="' . esc_attr(get_option('avp_accept_warning_text', 'You must accept that you are over 18')) . '" size="50">';
}

function age_verification_popup() {
    if (isset($_COOKIE['age_verified'])) return;
    ?>
    <div id="age-popup" style="position: fixed; top: 0; left: 0; width: 100%; height: 100%; background: rgba(0, 0, 0, 0.8); display: flex; justify-content: center; align-items: center; z-index: 9999;">
        <div style="background: white; padding: 20px; text-align: center; border-radius: 10px;">
            <h2><?php echo esc_html(get_option('avp_heading', 'Enter your birthdate')); ?></h2>
            <input type="text" id="day" placeholder="DD" maxlength="2" style="width: 50px; text-align: center;" />
            <input type="text" id="month" placeholder="MM" maxlength="2" style="width: 50px; text-align: center;" />
            <input type="text" id="year" placeholder="YYYY" maxlength="4" style="width: 80px; text-align: center;" />
            <br><br>
            <input type="checkbox" id="confirm-age"> <?php echo esc_html(get_option('avp_confirm_text', 'I confirm that I am over 18 years old')); ?>
            <br><br>
            <button onclick="checkAge()"> <?php echo esc_html(get_option('avp_button_text', 'Enter')); ?> </button>
            <p id="error-message" style="color: red; display: none;"></p>
        </div>
    </div>
    <script>
        function checkAge() {
            let day = document.getElementById('day').value;
            let month = document.getElementById('month').value;
            let year = document.getElementById('year').value;
            let confirmAge = document.getElementById('confirm-age').checked;
            let errorMessage = document.getElementById('error-message');
            
            if (!day || !month || !year) {
                errorMessage.textContent = 'Please enter a valid date of birth';
                errorMessage.style.display = 'block';
                return;
            }
            if (!confirmAge) {
                errorMessage.textContent = '<?php echo esc_html(get_option('avp_accept_warning_text', 'You must accept that you are over 18')); ?>';
                errorMessage.style.display = 'block';
                return;
            }
            
            let birthDateObj = new Date(year, month - 1, day);
            let today = new Date();
            let age = today.getFullYear() - birthDateObj.getFullYear();
            let monthDiff = today.getMonth() - birthDateObj.getMonth();
            let dayDiff = today.getDate() - birthDateObj.getDate();
            
            if (monthDiff < 0 || (monthDiff === 0 && dayDiff < 0)) {
                age--;
            }
            
            if (age >= 18) {
                document.getElementById('age-popup').style.display = 'none';
                document.cookie = "age_verified=true; path=/; max-age=" + (60*60*24*30);
            } else {
                errorMessage.textContent = '<?php echo esc_html(get_option('avp_warning_text', 'You are not old enough')); ?>';
                errorMessage.style.display = 'block';
            }
        }
    </script>
    <?php
}
add_action('wp_footer', 'age_verification_popup');
